@@ -106,7 +106,7 @@ else:
     WVD = weakref.WeakValueDictionary
 
 
-__version__ = "0.1.9"
+__version__ = "0.1.10"
 # FIXME: async calls, documentation, auth, summary – time it took etc.
 
 
@@ -1318,7 +1318,7 @@ class PipelineHandle:
 
     def scale_worker(self, replicas: int) -> bool:
         return cast(WorkerScale, self._client._request_json(
-            METHOD_POST, "/worker", {
+            METHOD_PUT, "/worker", {
                 "pipeline": self.get_id(),
                 "replicas": replicas,
                 "task": None,
